Raven
=====

Raven is a standalone (and the official) Python client for django-sentry.

It currently contains drop-in support for the following projects:

- Django
- Flask

Don't use a framework? No problem! Raven is easy to use in any Python application,
even if it's not on the web.

About Sentry
------------

Sentry provides you with a generic interface to view and interact with your error logs. With this
it allows you to interact and view near real-time information to discover issues and more
easily trace them in your application.

Docs: http://raven.rtfd.org